# Contributing

We welcome contributions from the community.

## License and CLA

This project is licensed under the Apache License 2.0.

By submitting a pull request, you agree that:
- Your contribution is your own work or you have the right to submit it
- Your contribution will be licensed under Apache 2.0
- You agree to the Contributor License Agreement (CLA)

The CLA is a lightweight Apache-style CLA intended to protect both
contributors and users of the project.

If you are contributing on behalf of a company, a Corporate CLA may
be required.